(function($) {
    "use strict";
    
    $.fn.linearSlider = function(options) {
        
        // default settings
        let settings = $.extend({
            speed: 1000,
            pause: 3000,
            autoplay: false
        }, options);
        
        // DOM objects
        const $slide = $(this);
        const $content = $slide.find('#slide-content ul');
        const $contentItems = $content.find('li');
        const $nav = $slide.find('#slide-nav ol');
        
        // system values
        let index = 0;
        let interval;
        
        initNav();
        setNav(0);
        
        if (settings.autoplay) {
            startSlider();
        }
        
        $nav.find('li').on('click', function(){
            const $nav = $(this).attr('nav');
            let $index = index + 1;
            let value;

            if ($nav > $index) {
                value = $nav - $index;
                index = $nav - 1; // reset index
                manageSlade.call(this, index, value, 'next');
            } else if ($nav < $index) {
                value = $index - $nav;
                index = $nav - 1; // reset index
                manageSlade.call(this, index, value, 'prev');
            } else {
                return false;
            }
        });
        
        function startSlider() {
            interval = setInterval(function() {
                  ++index;
                  if (index === $contentItems.length) {
                      index = 0;
                      $content.animate({'margin-left': 0}, settings.speed);
                      setNav(index);
                  } else {
                      $content.animate({'margin-left': '-='+$slide.width()}, settings.speed);
                      setNav(index);
                  }
            }, settings.pause);
        }
        
        function pauseSlider() {
            clearInterval(interval);
        }     
        
        // displays nav links
        function initNav() {
            for (let i = 1; i <= $contentItems.length; i++) {
                $nav.append('<li nav="'+i+'"></li>');
            }
        }
        
        // sets current nav link as active
        function setNav(value) {
            const $navItems = $nav.find('li');
            $($navItems[value]).addClass('active').siblings('li').removeClass('active');
        }
        
        function manageSlade(newIndex, newWidth, navKey) {
        
            pauseSlider();
            
            switch (navKey) {
                case 'next':
                    $content.animate({'margin-left': '-='+($slide.width() * newWidth)}, settings.speed);
                    break;
                case 'prev':
                    $content.animate({'margin-left': '+='+($slide.width() * newWidth)}, settings.speed);
                    break;
            }
            
            setNav(newIndex);
            
            if (settings.autoplay) {
                startSlider();
            }  
        }
    }
    
}(jQuery));
